@@ -1,18 +1,11 @@
+from typing import Optional, List, Tuple
 from tmsproviderapisdk.tms_extended_model import TmsExtendedModel
 
 
 class TmsAccountSubscription(TmsExtendedModel):
     _path_url = "/account_subscriptions/"
 
-    def __init__(self, account, start, tarif, id=None, stop=None):
-        """
-
-        :param account: int
-        :param start: string
-        :param tarif: int
-        :param id: int
-        :param stop: string
-        """
+    def __init__(self, account: int, start: str, tarif: int, id: int = None, stop: str = None):
         self.account = account
         self.start = start
         self.tarif = tarif
@@ -20,7 +13,7 @@ class TmsAccountSubscription(TmsExtendedModel):
         self.stop = stop
 
     @staticmethod
-    def _dict_to_object(as_dict):
+    def _dict_to_object(as_dict: dict) -> object:
         account_subscription = TmsAccountSubscription(
             account=as_dict["account"],
             id=as_dict["id"],
@@ -31,7 +24,8 @@ class TmsAccountSubscription(TmsExtendedModel):
         return account_subscription
 
     @classmethod
-    def get_list(cls, start=0, limit=50, sort="", account=None, tarif=None, quick_search=""):
+    def get_list(cls, start: int = 0, limit: int = 50, sort: str = "", account: int = None, tarif: int = None,
+                 quick_search: str = "") -> Optional[Tuple[List[object], int]]:
         account_subscriptions = super().get_list(start=start, limit=limit, sort=sort, account=account,
                                                  tarif=tarif, quick_search=quick_search)
 
