@@ -1,18 +1,12 @@
+from typing import List, Optional, Tuple
 from tmsproviderapisdk.tms_extended_model import TmsExtendedModel
 
 
 class TmsDeviceSubscription(TmsExtendedModel):
     _path_url = "/device_subscriptions/"
 
-    def __init__(self, device, start, tarif, id=None, stop=None):
-        """
+    def __init__(self, device: int, start: str, tarif: int, id: int = None, stop: str = None):
 
-        :param device: int
-        :param start: string
-        :param tarif: int
-        :param id: int
-        :param stop: string
-        """
         self.device = device
         self.start = start
         self.tarif = tarif
@@ -20,7 +14,7 @@ class TmsDeviceSubscription(TmsExtendedModel):
         self.stop = stop
 
     @staticmethod
-    def _dict_to_object(as_dict):
+    def _dict_to_object(as_dict: dict) -> object:
         device_subscription = TmsDeviceSubscription(
             device=as_dict["device"],
             id=as_dict["id"],
@@ -31,7 +25,8 @@ class TmsDeviceSubscription(TmsExtendedModel):
         return device_subscription
 
     @classmethod
-    def get_list(cls, start=0, limit=50, sort="", device=None, tarif=None, quick_search=""):
+    def get_list(cls, start: int = 0, limit: int = 50, sort: str = "", device: int = None, tarif: int = None,
+                 quick_search: str = "") -> Optional[Tuple[List[object], int]]:
 
         device_subscriptions = super().get_list(start=start, limit=limit, sort=sort, device=device, tarif=tarif,
                                                 quick_search=quick_search)
